@@ -25,6 +25,7 @@ class MiniECS:
         self.address = address
         self.port = port
         self.sock = socket.create_connection((address, port))
+        self.containers_list = []
 
     def create_container(self, name: str):
 
@@ -32,14 +33,11 @@ class MiniECS:
 
         if name not in self.containers_list:
 
-            if self.containers_list:
-                self.containers_list.append(name)
-            else:
-                self.containers_list = [name]
+            self.containers_list.append(name)
 
             try:
                 # Send data
-                message = b'{}'.format(name)
+                message = str.encode(name)
                 print('sending {!r}'.format(message))
                 self.sock.sendall(message)
 
